# Routing-Tabelle erzeugen

## Fachlicher Hintergrund

In der Spezifikation des Zugangsgateway des Versicherten (ZGdV)
([gemSpec\_Zugangsgateway\_Vers](https://fachportal.gematik.de/spezifikationen/online-produktivbetrieb/))
wird gefordern, dass das ZGdV OCSP-Anfragen von einem anfragenden "ePA-Frontend
des Versicherten" an die OCSP-Responder in der TI weiterleitet:

>   **A\_15869 - Zugangsgateway des Versicherten, Bereitstellung OCSP-Forwarder**
>
>   Ein Zugangsgateway des Versicherten MUSS folgende Vorgaben umsetzen:
>   
>   * Es MUSS unter dem in [gemSpec\_Aktensystem] Tabelle: Tab\_ePA\_FQDN
>   angegeben Pfadnamen für den key "ocspf" einen Proxy zur Statusabfrage über
>   sein vom ePA-Frontend des Versicherten schon genutztes HTTPS-Interface zur
>   Verfügung stellen (HTTP-POST, vgl. auch [RFC-6960, Appendix CgemSpec\_PKI]).
>   * Es MUSS über die Schnittstelle aus Spiegelstrich 1 OCSP-Requests [RFC-6960]
>   entgegen nehmen.
>   Aus einem solchen OCSP-Request MUSS es aus dem issuerKeyHash [RFC-
>   6960] die URL des entsprechenden OCSP-Responders in der TI ermitteln
>   (Datengrundlage ist die TSL der TI) und den OCSP-Request an diese ermittelte
>   URL weiterleiten.
>   * Es MUSS die erhaltenen OCSP-Response an das die OCSP-Anfrage
>   stellende ePA-Frontend des Versicherten unverändert weiterreichen.
>
>   [<=]
>
>   Auf Anfrage stellt die gematik eine Beispielimplementierung für A\_15869 Spiegelstrich 3
>   bereit.

D. h. beim ZGdV wird auf einer speziellen URL (bspw. "/ocsp", vgl. diesbez.
[gemSpec\_Aktensystem] Tabelle: Tab\_ePA\_FQDN beim Eintrag "ocspf") ein
HTTP-POST-Request ankommen, mit Content-Type "application/ocsp-request" (vgl.
[RFC-6960, Appendix C]). 

Ein solcher OCSP-Request hat eine genau definierte und sehr einfach zu erkennden
(i. S. v. wenig variable) Struktur:

      0  66: SEQUENCE {
      2  64:   SEQUENCE {
      4  62:     SEQUENCE {
      6  60:       SEQUENCE {
      8  58:         SEQUENCE {
     10   9:           SEQUENCE {
     12   5:             OBJECT IDENTIFIER sha1 (1 3 14 3 2 26)
     19   0:             NULL
           :             }
     21  20:           OCTET STRING
           :             FD 40 A1 51 E2 BC 48 25 61 53 3E 75 A3 C6 64 C5
           :             74 49 D1 8F
     43  20:           OCTET STRING
           :             EC 5C 18 E0 13 B4 43 6C 09 8C DF FA 3C 3C 5B 7E
           :             4B 70 84 46
     65   1:           INTEGER 2
           :           }
           :         }
           :       }
           :     }
           :   }

oder 

      0  94: SEQUENCE {
      2  92:   SEQUENCE {
      4  90:     SEQUENCE {
      6  88:       SEQUENCE {
      8  86:         SEQUENCE {
     10  13:           SEQUENCE {
     12   9:             OBJECT IDENTIFIER sha-256 (2 16 840 1 101 3 4 2 1)
     23   0:             NULL
           :             }
     25  32:           OCTET STRING
           :             60 CA 33 ED A0 83 73 91 B8 02 9F 01 DD C9 C0 62
           :             22 66 F5 08 1D B2 C3 B2 E2 9F AE 8E 30 E7 E6 B2
     59  32:           OCTET STRING
           :             90 9F B9 58 BA 12 49 B5 D2 F2 53 B0 F3 5A F2 52
           :             0A 1B FA C0 FF E1 A2 E0 BF 60 C7 9C 0D 45 67 92
     93   1:           INTEGER 2
           :           }
           :         }
           :       }
           :     }
           :   }

D. h. 

1. Das ZGdV erkennt anhand des "Content-Type"s, dass es sich um einen OCSP-Request handelt.
2. Es erkennt durch Bitvergleich der ersten 21 Bytes, ob es sich entweder 
   um einen "SHA-256"-OCSP-Request oder um einen "SHA-1"-OCSP-Request handelt.
3. Damit weiss das ZGdV bei welchem offset der issuerKeyHash (vgl. A\_15869, Punkt 3)
   beginnt und wie lang dieser ist.
4. Das ZGdV prüft die Länge des Requests und per Bitvergleich, ob die zu erwartenden 
   (i. S. v. konstanten) ASN.1-Struktur-Bytes sind (es ist hier keine aufwändige ASN.1-Dekodierung
   erforderlich).
5. Das ZGdV hat eine Tabelle mit der Zuordnung issuerKeyHash <-> URL (siehe unten GenRoutingTable.py).
6. Das ZGdV sendet den unveränderten OCSP-Request per HTTP-POST an die URL aus der Tabelle.
7. Was immer es als Antwort vom OCSP-Responder (vgl. URL aus der Tabelle) in
   der TI bekommt, sendet es als HTTP-Response an das anfragende FdV weiter.

Das ZGdV muss den OCSP-Request oder die OCSP-Repsonse nicht verstehen oder
irgendwie andersweitig parsen.

## Beispiel PU 
Das Programm GenRoutingTable.py erzeugt aus einer gültigen TSL (vgl. Chk-Signature-TSL.py),

1. eine Abbildung issuerKeyHash (SHA-1) <-> URL, und
2. eine Abbildung issuerKeyHash (SHA-256) <-> URL.

Die TSL für PU und für die TU kann man unter
[TSL.xml](https://download.tsl.ti-dienste.de/TSL.xml) und
[TSL-testref.xml](https://download-testref.tsl.ti-dienste.de/TSL-testref.xml)
erhalten.

Beispiel-Ausführung:

    $ ./GenRoutingTable.py TSL.xml
    TSL-id: ID331320190827230000Z
    TSL erzeugt am 2019-08-27T23:00:00Z
    nächstes Update 2019-09-26T23:00:00Z
    
    Routing-Tabelle im JSON-Format:
    {
        "07eb35f9ed657093125a08b6b6b7251b00e6d7290d37f76ca6ab5dfc8abec61b": "http://ocsp1.atos.tsp-egk.telematik",
        "097dd2ecafc610289cf8a79daa403f1ac41fb547": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "0a1f3f265f8f2d71c7965324d2f6457344be07d9c3f7e538202f0c444654a5a9": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eA.medisign.de%3A8080%2Focsp",
        "0fb5fd3c20a426033540121bf3c57cffff49cef08d25ed0e9602ced7b00152d7": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "102d3ce379054d3945ec3961b4add68a8406e4d8f816ce20639fe8c0a991492b": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "1414b6b08db8e317b17b1acc81e29108fa9fcd4b": "http://ocsp1.atos.tsp-egk.telematik",
        "14ded5fd38944b38938335ec668d7172747e5a7d": "http://ocsp.bdr.tsp-hba.telematik",
        "15611416ecdaed8c48f36cc10f62272eb2d41c5636d9d941a6c4d266e4b00ee5": "http://ocsp.bdr.tsp-smc-b.telematik",
        "159bd00d6c784d6ac8eab446e64611f939aad9ff": "http://ocsp1.atos.tsp-egk.telematik",
        "171553637d2c627f0af276ab54d65445fff29c51": "http://ocsp-smcb.tsi.tsp-smc-b.telematik/ocspr",
        "1a2efd3464f1b95c878eeec6ecbb70dbf29d1e4a3644e5f133cc7d47f5a3b8b5": "http://ocsp1.atos.tsp-egk.telematik",
        "1aed9befc190da65223f7431a0f3ebb7685e38ba": "http://ocsp-hba.tsi.tsp-hba.telematik/ocspr",
        "216c0537f4d017a4cf4389315f79589ce2303d2a52d1005b5adb91d54463ce67": "http://ocsp-hba.tsi.tsp-hba.telematik/ocspr",
        "2641ecf8115a95d37577daabb0aad6d0dba5fd61": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "28171dbbcad34bf78e15819d600b3427edb07b50": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-ePTA.medisign.de%3A8080%2Focsp",
        "2af62411667b55f3f49cf351432836fe0e93837f": "http://ocsp-smcb.tsi.tsp-smc-b.telematik/ocspr",
        "2b2710c917992dda6a05dd4469a8166bb0cf07c1": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eA.medisign.de%3A8080%2Focsp",
        "2d6d1e119c9ebc98728cb5c55e6892cbc69d43d5e9e3871282abd2499a048e2d": "http://ocsp1.atos.tsp-egk.telematik",
        "2d7d47a533ad249b23754601f22e9082567434d130c533cb7f64a52ecffee9a3": "http://ocsp.tsl.telematik/ocsp",
        "2e2de6dd2055b7b74d186788badf17bb614dd292e5159d2c42b633b27f600860": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eZAA.medisign.de%3A8080%2Focsp",
        "2f485df0ffef1139debae4ce0c53d721b4bd500d2e520cab1dcaa215420878ab": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "310819aa628051a0ddc45562d82fd4ad4c453ea7": "http://ocsp1.atos.tsp-egk.telematik",
        "32c06d315a816b3317e99156fb0ebf67f695d8ec4f8fd8b80ec856de848ba5a8": "http://ocsp1.atos.tsp-egk.telematik",
        "32c9d99143d30edfcdba2e86674ef59d65a9758c07d99aa6da206b65ad943f64": "http://ocsp-smcb.tsi.tsp-smc-b.telematik/ocspr",
        "359a170556df65a4fa5134a2473a06cd38cd502d09b1c9321ac0a6d2fd9e584b": "http://ti-ocsp-smcb.medisign.tsp-smc-b.telematik:8080/ocsp",
        "35c9ea6220bfa8f3dfd05a401a3c4818cae1f91b": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "38c2f6310fb3d659f30414fbcb8f876e671a5d81": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "38e00cdd21f740ae30e7709173c0ace227f4e79c": "http://ocsp.tsl.telematik/ocsp",
        "3ca6ee2110a062181795f5d7bd3362a83d32c008d2a531a47c961fd8937576f4": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "41c6af99c6c492a554027ef33fcb54a312853f6e4fb30755154a722fe048686c": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "42b899c13a588208599c18cf3947669de133fae6": "http://ocsp.komp-ca.telematik/ocsp",
        "43614a6b9565f8143f990018c78567e1dabcc9d10350c1c143463bea174ee053": "http://ocsp.bdr.tsp-hba.telematik",
        "4a3a8c58e3588ad290d517dfe80bddff90f19007179a6daf7ee8cc891ebaa40f": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "4a843a9e4c7c4d613e935c8967a3098c2802a1da60671cfe9d83cc5bf7f3ce46": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "4b1a00655abd865e048d69dd2f7ee6c2705a93ea": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "4c4248dd965eda8ab1732fd8c7d63e63c1a760b8": "http://ti-ocsp-smcb.medisign.tsp-smc-b.telematik:8080/ocsp",
        "4def0393a8e6f35ecc9c8e85d5bcdd4a326317ac": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-zod2.medisign.de%3A8080%2Focsp",
        "4fef05190a566ed4f8dba5fa72176711033f5ed884b546af2a724c2e250fbe33": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-zod2.medisign.de%3A8080%2Focsp",
        "521e10ac6b279232f4600f2456578cc1be4e72fc6d61756a9fa413410deae116": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "537fac865bd8eba62b0085e4862287fdee08642975ef4ef670d64e79963ced57": "http://ocsp-hba.tsi.tsp-hba.telematik/ocspr",
        "599962cd2b8439064ce546a2f95d2fd40b680e27": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eA.medisign.de%3A8080%2Focsp",
        "5f5114bb98201927908bd571e23efaf19e10bd40": "http://ocsp1.atos.tsp-egk.telematik",
        "6214f3d59dbfe44a911aa2c092750365b411f38b": "http://ocsp1.atos.tsp-egk.telematik",
        "657cbd744e7b3525bbb85f88884e4a3279bf5aa8": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "690aa71f7c224bd4f681cf5f73b6c62646ad966c": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-zod2.medisign.de%3A8080%2Focsp",
        "6abdc0383272c291672da1a141490813e7e7fe77": "http://download.crl.ti-dienste.de/crl/vpnk-ca1.crl",
        "6ed982b14798626e266b6f74cdb3435cb79cc007": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eZAA.medisign.de%3A8080%2Focsp",
        "6f91661f5727edfe3425f9cb24d327945d788f975b9bda1c25e82c49906b486e": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-ePTA.medisign.de%3A8080%2Focsp",
        "71beccac2f46f7af7503ce983b86e2f2bc56732e": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "720575b07a87dd08750d350a49e826a305522d1378628095002940fefce6e6bc": "http://ocsp1.atos.tsp-egk.telematik",
        "76d94708965eb780fb1378387279c1f9f03f664c5b8142b25521ddf46c5af141": "http://ocsp.komp-ca.telematik/ocsp",
        "7720fe98dbf9853cb489ce95b776650786a38725": "http://ocsp1.atos.tsp-egk.telematik",
        "791eb6114f23222136542fd5e2a3f071f5b0b33c914cfe336f3defdbed8b92f4": "http://ocsp1.atos.tsp-egk.telematik",
        "794be575dc1eb7497a59451fb9c54d73d52ab6c9b8b23a199a8e108186511db3": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eZAA.medisign.de%3A8080%2Focsp",
        "79e847453409da3f422b27ecbf399d208f7408b2": "http://ocsp1.atos.tsp-egk.telematik",
        "7cd46422fc3386a96678788ea0089bcd241c1b2a2b7e944b1c6e349a5ab3ea0f": "http://ocsp1.atos.tsp-egk.telematik",
        "7ed8a87f253fa18c19b0c24a498b3469696cb2b5402567a66882fa0db471b6e5": "http://ocsp1.atos.tsp-egk.telematik",
        "82bc5f221e34f7cefa1ed1b8e68eba693215e613": "http://ocsp1.atos.tsp-egk.telematik",
        "8348855a6ba8f7f4f41f86dff92122249b81019015decf3ba273f3d6724bdbd2": "http://ocsp1.atos.tsp-egk.telematik",
        "83d7323a5540402e6e563a0170ec2271952718bc": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "8d4cab56f6a5f780ccbac4fc5fe9776f6494a292": "http://ocsp1.atos.tsp-egk.telematik",
        "90a763f542945f70d0b277b410a8f39ea1fb32fe285271de0929297255171e4d": "http://ocsp1.atos.tsp-egk.telematik",
        "9150167a63834ab9c5b106c71e65065e68c7ef37c16fafaf9c8e3927cad858be": "http://ocsp1.atos.tsp-egk.telematik",
        "9ba5620fe8c439eceee7678be4d2e6430eaaf1dd": "http://ocsp1.atos.tsp-egk.telematik",
        "9d121b291082a794b6146e7c4b2d7d162023874c31970e0dbb23a4274296ba21": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "a0b7552af3291012874b9bb2250b9e7f5ff516627fb26a0115e9e7e00247c4ea": "http://ocsp1.atos.tsp-egk.telematik",
        "a79c1941949bd11de5b8833ab20bb3d6560bf63386817cc03ddef58102588430": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "a7e7605a2a91651142ba8469fd364c8d2b2cfe0ddd04ede291319498c23b62cb": "http://ocsp.komp-ca.telematik/ocsp",
        "a7ea85d6dff6ce26a887bda1e04e9cd27886a3be89e5bf897f8a6c229f2635be": "http://download.crl.ti-dienste.de/crl/vpnk-ca1.crl",
        "abfbfcf35eccbe4ce428c0bc663d0622b462fe76e4b7375e813a87f16d9ceb00": "http://ocsp.bdr.tsp-hba.telematik",
        "ac2936d16ab2ccb3a2724cd05bae4966cafcf69718ac1cbd0c5dfb3ec416b7ff": "http://ocsp1.atos.tsp-egk.telematik",
        "ad1199685faaa2e4107822804f7dae9f57f0d27404a2cd48aabca7815f2f48d9": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "ad1f31bb64352f9df766d1021aa9133b3097602e4818606fba97f633ee7154cf": "http://download.crl.ti-dienste.de/crl/vpnk-ca1.crl",
        "aea3bdb4bacc1736c80f8dd211f08beeed2eec9b9fbe1a41679cec069a1700c0": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-zod2.medisign.de%3A8080%2Focsp",
        "af30a956287ab6615c8a33d501b6d8585463314d": "http://ocsp1.atos.tsp-egk.telematik",
        "be2001f194a5841fb9b782ef9e201dcd188713c09f829b91f2098bd10c684e0c": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "c1db45fdcd755ea321e6c7a29b192e45752dcda9a8eb14e0b64e0ae209e7807c": "http://ocsp1.atos.tsp-egk.telematik",
        "c3185d9b936eff442a48043d6f65c9a61cb06220": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "c64e9848a35e2f733fc898a1e6f547a835c8853a": "http://ocsp.bdr.tsp-smc-b.telematik",
        "c730a2a3a8f94834beb0096ac147f23f5f972802": "http://ocsp1.atos.tsp-egk.telematik",
        "cc685c7d3ba3a3a4f2af149032d3d6e3d7fc63be": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "d004db051c6e70249bc65b352b28c64b6715008434bf30bad8bcb0c69bcc9ecf": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "d4729f2fcd02dc6bb37bb2b454188ad663753aa598bc4b91d0f9295ebc7bedb9": "http://ocsp-smcb.tsi.tsp-smc-b.telematik/ocspr",
        "d4fffdef4bc1b19506bbf514bf90c3706134020ae4f0d6ca8dabf0f55bfaeb19": "http://ocsp1.atos.tsp-egk.telematik",
        "da3d0204166ab35bab313208fa7a026ad55c09f4": "http://ocsp1.atos.tsp-egk.telematik",
        "dac6a3d34ad9fb3ddf740e2a790dcfc481fc9430": "http://ocsp1.atos.tsp-egk.telematik",
        "dde4ee0a453a7fe87edce3a82af83c978ac9a6ee03f2cc9bd8972a9f6d4276f3": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eA.medisign.de%3A8080%2Focsp",
        "e159185581e551c3a4e9e5e692d2949ee32e11a7": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "e1cd791e91b46f0f51158caee5b2d231446c94a45a45b3b5c7681cf856817480": "http://ocsp1.atos.tsp-egk.telematik",
        "e295e85c6c6feccffa6462c8dccfa5c39fa4b288": "http://ocsp-hba.tsi.tsp-hba.telematik/ocspr",
        "e3b27ab778008c794fda8e5fa6b5069a0d06af62": "http://ocsp1.atos.tsp-egk.telematik",
        "ec120e565a88256fbb0741f2e614ba409bbee07e": "http://ocsp.bdr.tsp-smc-b.telematik",
        "f017016c50364d9d21e58c99e2a41f1f1ba94d78": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "f090ae4954fa9edb5272e81e3a62d355b9becb18d783bece9c19f5b7f3f21e32": "http://ocsp.bdr.tsp-smc-b.telematik",
        "f2243b3b22776658e6d431c37f1bc4c1ae758aab": "http://ocsp.bdr.tsp-hba.telematik",
        "f4e23b61186783c002aae87c64272a9276daedc3": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "f514d213ba2f31713239e61f3d9004389ba076d8": "http://ocsp1.atos.tsp-egk.telematik",
        "f6f9f0076c768d6d3762bce44515804c94237810": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eZAA.medisign.de%3A8080%2Focsp",
        "f7b2031c7499ad6421090e05d8be0056fc7a96a4": "http://download.crl.ti-dienste.de/crl/vpnk-ca1.crl",
        "fdb5b91779bdb86b1e2957223dc2b9b38981cf4d": "http://ocsp.komp-ca.telematik/ocsp"
    }
    
    $ ./GenRoutingTable.py TSL.xml -v
    TSL-id: ID331320190827230000Z
    TSL erzeugt am 2019-08-27T23:00:00Z
    nächstes Update 2019-09-26T23:00:00Z
    TSP "medisign GmbH"
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=DEMDS CA für Zahnärzte 2:PN,O=medisign GmbH,C=DE
    MIIFLjCCBBagAwIBAgIBDjANBgkqhkiG9w0BAQsFADBfMQswCQYDVQQGEwJE
    http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eZAA.medisign.de%3A8080%2Focsp
    Zertifikat ("DE, medisign GmbH, DEMDS CA für Zahnärzte 2:PN", SN: 14, gültig bis 2019-12-09T15:59).
    SHA-1: 6ed982b14798626e266b6f74cdb3435cb79cc007
    SHA-256: 794be575dc1eb7497a59451fb9c54d73d52ab6c9b8b23a199a8e108186511db3
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=DEMDS CA für Ärzte 5:PN,O=medisign GmbH,C=DE
    MIIFMDCCBBigAwIBAgIBLTANBgkqhkiG9w0BAQsFADBEMQswCQYDVQQGEwJE
    http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eA.medisign.de%3A8080%2Focsp
    Zertifikat ("DE, medisign GmbH, DEMDS CA für Ärzte 5:PN", SN: 45, gültig bis 2020-02-14T09:41).
    SHA-1: 599962cd2b8439064ce546a2f95d2fd40b680e27
    SHA-256: 0a1f3f265f8f2d71c7965324d2f6457344be07d9c3f7e538202f0c444654a5a9
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=DEMDS CA für Psychotherapeuten 3:PN,O=medisign GmbH,C=DE
    MIIFfzCCBGegAwIBAgIBHDANBgkqhkiG9w0BAQsFADBPMQswCQYDVQQGEwJE
    http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-ePTA.medisign.de%3A8080%2Focsp
    Zertifikat ("DE, medisign GmbH, DEMDS CA für Psychotherapeuten 3:PN", SN: 28, gültig bis 2020-02-14T09:36).
    SHA-1: 28171dbbcad34bf78e15819d600b3427edb07b50
    SHA-256: 6f91661f5727edfe3425f9cb24d327945d788f975b9bda1c25e82c49906b486e
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=DEMDS CA für Zahnärzte 1:PN,O=medisign GmbH,C=DE
    MIIFLjCCBBagAwIBAgIBDTANBgkqhkiG9w0BAQsFADBfMQswCQYDVQQGEwJE
    http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eZAA.medisign.de%3A8080%2Focsp
    Zertifikat ("DE, medisign GmbH, DEMDS CA für Zahnärzte 1:PN", SN: 13, gültig bis 2019-12-09T15:59).
    SHA-1: f6f9f0076c768d6d3762bce44515804c94237810
    SHA-256: 2e2de6dd2055b7b74d186788badf17bb614dd292e5159d2c42b633b27f600860
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=DEMDS CA für Ärzte 6:PN,O=medisign GmbH,C=DE
    MIIFMDCCBBigAwIBAgIBLjANBgkqhkiG9w0BAQsFADBEMQswCQYDVQQGEwJE
    http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eA.medisign.de%3A8080%2Focsp
    Zertifikat ("DE, medisign GmbH, DEMDS CA für Ärzte 6:PN", SN: 46, gültig bis 2020-02-14T09:43).
    SHA-1: 2b2710c917992dda6a05dd4469a8166bb0cf07c1
    SHA-256: dde4ee0a453a7fe87edce3a82af83c978ac9a6ee03f2cc9bd8972a9f6d4276f3
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=MED-ZOD2-CA-4:PN,O=medisign GmbH,C=DE
    MIIFCTCCA/GgAwIBAgIBTjANBgkqhkiG9w0BAQsFADA8MQswCQYDVQQGEwJE
    http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-zod2.medisign.de%3A8080%2Focsp
    Zertifikat ("DE, medisign GmbH, MED-ZOD2-CA-4:PN", SN: 78, gültig bis 2020-01-27T10:50).
    SHA-1: 690aa71f7c224bd4f681cf5f73b6c62646ad966c
    SHA-256: 4fef05190a566ed4f8dba5fa72176711033f5ed884b546af2a724c2e250fbe33
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=MED-ZOD2-CA-3:PN,O=medisign GmbH,C=DE
    MIIFCTCCA/GgAwIBAgIBTTANBgkqhkiG9w0BAQsFADA8MQswCQYDVQQGEwJE
    http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-zod2.medisign.de%3A8080%2Focsp
    Zertifikat ("DE, medisign GmbH, MED-ZOD2-CA-3:PN", SN: 77, gültig bis 2020-01-27T10:50).
    SHA-1: 4def0393a8e6f35ecc9c8e85d5bcdd4a326317ac
    SHA-256: aea3bdb4bacc1736c80f8dd211f08beeed2eec9b9fbe1a41679cec069a1700c0
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=MESIG.SMCB-CA1,OU=Institution des Gesundheitswesens-CA der Telematikinfrastruktur,O=Medisign GmbH,C=DE
    MIIENDCCAxygAwIBAgIBDDANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ti-ocsp-smcb.medisign.tsp-smc-b.telematik:8080/ocsp
    Zertifikat ("DE, Medisign GmbH, Institution des Gesundheitswesens-CA der Telematikinfrastruktur, MESIG.SMCB-CA1", SN: 12, gültig bis 2026-06-10T07:32).
    SHA-1: 4c4248dd965eda8ab1732fd8c7d63e63c1a760b8
    SHA-256: 359a170556df65a4fa5134a2473a06cd38cd502d09b1c9321ac0a6d2fd9e584b
    TSP "arvato Systems GmbH"
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=GEM.KOMP-CA3,OU=Komponenten-CA der Telematikinfrastruktur,O=gematik GmbH,C=DE
    MIIEGjCCAwKgAwIBAgIBCTANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp.komp-ca.telematik/ocsp
    Zertifikat ("DE, gematik GmbH, Komponenten-CA der Telematikinfrastruktur, GEM.KOMP-CA3", SN: 9, gültig bis 2026-03-14T12:23).
    SHA-1: fdb5b91779bdb86b1e2957223dc2b9b38981cf4d
    SHA-256: a7e7605a2a91651142ba8469fd364c8d2b2cfe0ddd04ede291319498c23b62cb
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=GEM.VPNK-CA1,OU=VPN-Zugangsdienst-CA der Telematikinfrastruktur,O=gematik GmbH,C=DE
    MIIEfzCCA2egAwIBAgIBBjANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://download.crl.ti-dienste.de/crl/vpnk-ca1.crl
    Zertifikat ("DE, gematik GmbH, VPN-Zugangsdienst-CA der Telematikinfrastruktur, GEM.VPNK-CA1", SN: 6, gültig bis 2023-03-17T14:03).
    SHA-1: 6abdc0383272c291672da1a141490813e7e7fe77
    SHA-256: ad1f31bb64352f9df766d1021aa9133b3097602e4818606fba97f633ee7154cf
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=GEM.TSL-CA1,OU=TSL-Signer-CA der Telematikinfrastruktur,O=gematik GmbH,C=DE
    MIIEGDCCAwCgAwIBAgIBAjANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp.tsl.telematik/ocsp
    Zertifikat ("DE, gematik GmbH, TSL-Signer-CA der Telematikinfrastruktur, GEM.TSL-CA1", SN: 2, gültig bis 2023-02-17T10:18).
    SHA-1: 38e00cdd21f740ae30e7709173c0ace227f4e79c
    SHA-256: 2d7d47a533ad249b23754601f22e9082567434d130c533cb7f64a52ecffee9a3
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=GEM.KOMP-CA1,OU=Komponenten-CA der Telematikinfrastruktur,O=gematik GmbH,C=DE
    MIIEeTCCA2GgAwIBAgIBAzANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp.komp-ca.telematik/ocsp
    Zertifikat ("DE, gematik GmbH, Komponenten-CA der Telematikinfrastruktur, GEM.KOMP-CA1", SN: 3, gültig bis 2023-03-17T14:02).
    SHA-1: 42b899c13a588208599c18cf3947669de133fae6
    SHA-256: 76d94708965eb780fb1378387279c1f9f03f664c5b8142b25521ddf46c5af141
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=GEM.VPNK-CA3,OU=VPN-Zugangsdienst-CA der Telematikinfrastruktur,O=gematik GmbH,C=DE
    MIIEIDCCAwigAwIBAgIBCzANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://download.crl.ti-dienste.de/crl/vpnk-ca1.crl
    Zertifikat ("DE, gematik GmbH, VPN-Zugangsdienst-CA der Telematikinfrastruktur, GEM.VPNK-CA3", SN: 11, gültig bis 2026-03-14T12:24).
    SHA-1: f7b2031c7499ad6421090e05d8be0056fc7a96a4
    SHA-256: a7ea85d6dff6ce26a887bda1e04e9cd27886a3be89e5bf897f8a6c229f2635be
    TSP "Atos Information Technology GmbH"
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA201,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEZjCCA06gAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGYMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA201", SN: 1000000, gültig bis 2025-02-09T13:58).
    SHA-1: c730a2a3a8f94834beb0096ac147f23f5f972802
    SHA-256: c1db45fdcd755ea321e6c7a29b192e45752dcda9a8eb14e0b64e0ae209e7807c
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA9,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEbjCCA1agAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGWMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA9", SN: 1000000, gültig bis 2026-10-02T12:17).
    SHA-1: 9ba5620fe8c439eceee7678be4d2e6430eaaf1dd
    SHA-256: 791eb6114f23222136542fd5e2a3f071f5b0b33c914cfe336f3defdbed8b92f4
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=Atos eGK-CA 8,OU=Trustcenter,O=Atos Information Technology GmbH,C=DE
    MIIEAjCCAuqgAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMGYxCzAJBgNVBAYT
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Trustcenter, Atos eGK-CA 8", SN: 1000000, gültig bis 2023-06-09T10:42).
    SHA-1: e3b27ab778008c794fda8e5fa6b5069a0d06af62
    SHA-256: 1a2efd3464f1b95c878eeec6ecbb70dbf29d1e4a3644e5f133cc7d47f5a3b8b5
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=Atos Origin eGK-CA 7,OU=Trustcenter,O=Atos Origin GmbH,C=DE
    MIID8DCCAtigAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMF0xCzAJBgNVBAYT
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Origin GmbH, Trustcenter, Atos Origin eGK-CA 7", SN: 1000000, gültig bis 2019-09-15T13:01).
    SHA-1: 5f5114bb98201927908bd571e23efaf19e10bd40
    SHA-256: 07eb35f9ed657093125a08b6b6b7251b00e6d7290d37f76ca6ab5dfc8abec61b
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=Atos Origin eGK-CA 5,OU=Trustcenter,O=Atos Origin GmbH,C=DE
    MIID8DCCAtigAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMF0xCzAJBgNVBAYT
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Origin GmbH, Trustcenter, Atos Origin eGK-CA 5", SN: 1000000, gültig bis 2019-09-14T15:04).
    SHA-1: f514d213ba2f31713239e61f3d9004389ba076d8
    SHA-256: 9150167a63834ab9c5b106c71e65065e68c7ef37c16fafaf9c8e3927cad858be
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=Atos Origin eGK-CA 4,OU=Trustcenter,O=Atos Origin GmbH,C=DE
    MIID8DCCAtigAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMF0xCzAJBgNVBAYT
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Origin GmbH, Trustcenter, Atos Origin eGK-CA 4", SN: 1000000, gültig bis 2019-09-14T15:03).
    SHA-1: dac6a3d34ad9fb3ddf740e2a790dcfc481fc9430
    SHA-256: e1cd791e91b46f0f51158caee5b2d231446c94a45a45b3b5c7681cf856817480
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA5,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEbjCCA1agAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGWMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA5", SN: 1000000, gültig bis 2026-06-19T12:55).
    SHA-1: 8d4cab56f6a5f780ccbac4fc5fe9776f6494a292
    SHA-256: 7ed8a87f253fa18c19b0c24a498b3469696cb2b5402567a66882fa0db471b6e5
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA7,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEbjCCA1agAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGWMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA7", SN: 1000000, gültig bis 2026-08-30T12:24).
    SHA-1: da3d0204166ab35bab313208fa7a026ad55c09f4
    SHA-256: 8348855a6ba8f7f4f41f86dff92122249b81019015decf3ba273f3d6724bdbd2
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA202,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEcjCCA1qgAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGYMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA202", SN: 1000000, gültig bis 2026-11-14T15:06).
    SHA-1: 310819aa628051a0ddc45562d82fd4ad4c453ea7
    SHA-256: 2d6d1e119c9ebc98728cb5c55e6892cbc69d43d5e9e3871282abd2499a048e2d
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA12,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEcDCCA1igAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGXMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA12", SN: 1000000, gültig bis 2027-01-29T16:40).
    SHA-1: 82bc5f221e34f7cefa1ed1b8e68eba693215e613
    SHA-256: ac2936d16ab2ccb3a2724cd05bae4966cafcf69718ac1cbd0c5dfb3ec416b7ff
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA11,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEcDCCA1igAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGXMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA11", SN: 1000000, gültig bis 2027-01-29T16:38).
    SHA-1: 6214f3d59dbfe44a911aa2c092750365b411f38b
    SHA-256: a0b7552af3291012874b9bb2250b9e7f5ff516627fb26a0115e9e7e00247c4ea
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA1,SERIALNUMBER=00000-0001000000,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEmDCCA4CgAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGxMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, 00000-0001000000, ATOS.EGK-CA1", SN: 1000000, gültig bis 2023-11-03T15:36).
    SHA-1: 7720fe98dbf9853cb489ce95b776650786a38725
    SHA-256: 32c06d315a816b3317e99156fb0ebf67f695d8ec4f8fd8b80ec856de848ba5a8
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA2,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEYjCCA0qgAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGWMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA2", SN: 1000000, gültig bis 2024-03-17T15:00).
    SHA-1: 1414b6b08db8e317b17b1acc81e29108fa9fcd4b
    SHA-256: d4fffdef4bc1b19506bbf514bf90c3706134020ae4f0d6ca8dabf0f55bfaeb19
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA3,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEYjCCA0qgAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGWMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA3", SN: 1000000, gültig bis 2024-03-17T15:11).
    SHA-1: af30a956287ab6615c8a33d501b6d8585463314d
    SHA-256: 90a763f542945f70d0b277b410a8f39ea1fb32fe285271de0929297255171e4d
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA4,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEYjCCA0qgAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGWMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA4", SN: 1000000, gültig bis 2024-03-17T15:11).
    SHA-1: 159bd00d6c784d6ac8eab446e64611f939aad9ff
    SHA-256: 7cd46422fc3386a96678788ea0089bcd241c1b2a2b7e944b1c6e349a5ab3ea0f
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=ATOS.EGK-CA13,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=Atos Information Technology GmbH,C=DE
    MIIEcDCCA1igAwIBAgIDD0JAMA0GCSqGSIb3DQEBCwUAMIGXMQswCQYDVQQG
    http://ocsp1.atos.tsp-egk.telematik
    Zertifikat ("DE, Atos Information Technology GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, ATOS.EGK-CA13", SN: 1000000, gültig bis 2027-05-08T12:53).
    SHA-1: 79e847453409da3f422b27ecbf399d208f7408b2
    SHA-256: 720575b07a87dd08750d350a49e826a305522d1378628095002940fefce6e6bc
    TSP "T-Systems International GmbH"
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=TSYSI.SMCB-CA1,OU=Institution des Gesundheitswesens-CA der Telematikinfrastruktur,O=T-Systems International GmbH,C=DE
    MIIEQzCCAyugAwIBAgIBCTANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp-smcb.tsi.tsp-smc-b.telematik/ocspr
    Zertifikat ("DE, T-Systems International GmbH, Institution des Gesundheitswesens-CA der Telematikinfrastruktur, TSYSI.SMCB-CA1", SN: 9, gültig bis 2023-12-07T09:45).
    SHA-1: 2af62411667b55f3f49cf351432836fe0e93837f
    SHA-256: 32c9d99143d30edfcdba2e86674ef59d65a9758c07d99aa6da206b65ad943f64
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=T-Systems eGK CA 3,OU=Trust Center Deutsche Telekom,O=T-Systems International GmbH,C=DE
    MIIEOjCCAyKgAwIBAgIBATANBgkqhkiG9w0BAQsFADB5MQswCQYDVQQGEwJE
    http://ocsp-egk.tsi.tsp-egk.telematik/ocspr
    Zertifikat ("DE, T-Systems International GmbH, Trust Center Deutsche Telekom, T-Systems eGK CA 3", SN: 1, gültig bis 2021-08-25T23:59).
    SHA-1: 657cbd744e7b3525bbb85f88884e4a3279bf5aa8
    SHA-256: 4a3a8c58e3588ad290d517dfe80bddff90f19007179a6daf7ee8cc891ebaa40f
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=TSYSI.SMCB-CA2,OU=Institution des Gesundheitswesens-CA der Telematikinfrastruktur,O=T-Systems International GmbH,C=DE
    MIIEQzCCAyugAwIBAgIBEDANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp-smcb.tsi.tsp-smc-b.telematik/ocspr
    Zertifikat ("DE, T-Systems International GmbH, Institution des Gesundheitswesens-CA der Telematikinfrastruktur, TSYSI.SMCB-CA2", SN: 16, gültig bis 2026-12-01T11:03).
    SHA-1: 171553637d2c627f0af276ab54d65445fff29c51
    SHA-256: d4729f2fcd02dc6bb37bb2b454188ad663753aa598bc4b91d0f9295ebc7bedb9
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=TSYSI.HBA-CA1,OU=Heilberufsausweis-CA der Telematikinfrastruktur,O=T-Systems International GmbH,C=DE
    MIIEMjCCAxqgAwIBAgIBCjANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp-hba.tsi.tsp-hba.telematik/ocspr
    Zertifikat ("DE, T-Systems International GmbH, Heilberufsausweis-CA der Telematikinfrastruktur, TSYSI.HBA-CA1", SN: 10, gültig bis 2024-03-15T12:47).
    SHA-1: 1aed9befc190da65223f7431a0f3ebb7685e38ba
    SHA-256: 216c0537f4d017a4cf4389315f79589ce2303d2a52d1005b5adb91d54463ce67
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=T-Systems eGK CA 4,OU=Trust Center Deutsche Telekom,O=T-Systems International GmbH,C=DE
    MIIEBjCCAu6gAwIBAgIBATANBgkqhkiG9w0BAQsFADB5MQswCQYDVQQGEwJE
    http://ocsp-egk.tsi.tsp-egk.telematik/ocspr
    Zertifikat ("DE, T-Systems International GmbH, Trust Center Deutsche Telekom, T-Systems eGK CA 4", SN: 1, gültig bis 2022-02-18T23:59).
    SHA-1: f4e23b61186783c002aae87c64272a9276daedc3
    SHA-256: 9d121b291082a794b6146e7c4b2d7d162023874c31970e0dbb23a4274296ba21
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=TSYSI.EGK-CA5,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=T-Systems International GmbH,C=DE
    MIIEPzCCAyegAwIBAgIBATANBgkqhkiG9w0BAQsFADCBkzELMAkGA1UEBhMC
    http://ocsp-egk.tsi.tsp-egk.telematik/ocspr
    Zertifikat ("DE, T-Systems International GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, TSYSI.EGK-CA5", SN: 1, gültig bis 2024-05-29T23:59).
    SHA-1: 4b1a00655abd865e048d69dd2f7ee6c2705a93ea
    SHA-256: ad1199685faaa2e4107822804f7dae9f57f0d27404a2cd48aabca7815f2f48d9
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=TSYSI.EGK-CA6,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=T-Systems International GmbH,C=DE
    MIIEPzCCAyegAwIBAgIBATANBgkqhkiG9w0BAQsFADCBkzELMAkGA1UEBhMC
    http://ocsp-egk.tsi.tsp-egk.telematik/ocspr
    Zertifikat ("DE, T-Systems International GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, TSYSI.EGK-CA6", SN: 1, gültig bis 2024-05-29T23:59).
    SHA-1: e159185581e551c3a4e9e5e692d2949ee32e11a7
    SHA-256: 0fb5fd3c20a426033540121bf3c57cffff49cef08d25ed0e9602ced7b00152d7
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=TSYSI.HBA-CA2,OU=Heilberufsausweis-CA der Telematikinfrastruktur,O=T-Systems International GmbH,C=DE
    MIIEMjCCAxqgAwIBAgIBETANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp-hba.tsi.tsp-hba.telematik/ocspr
    Zertifikat ("DE, T-Systems International GmbH, Heilberufsausweis-CA der Telematikinfrastruktur, TSYSI.HBA-CA2", SN: 17, gültig bis 2026-12-01T11:04).
    SHA-1: e295e85c6c6feccffa6462c8dccfa5c39fa4b288
    SHA-256: 537fac865bd8eba62b0085e4862287fdee08642975ef4ef670d64e79963ced57
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=TSYSI.EGK-CA7,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=T-Systems International GmbH,C=DE
    MIIEPzCCAyegAwIBAgIBATANBgkqhkiG9w0BAQsFADCBkzELMAkGA1UEBhMC
    http://ocsp-egk.tsi.tsp-egk.telematik/ocspr
    Zertifikat ("DE, T-Systems International GmbH, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, TSYSI.EGK-CA7", SN: 1, gültig bis 2027-05-01T23:59).
    SHA-1: 2641ecf8115a95d37577daabb0aad6d0dba5fd61
    SHA-256: 102d3ce379054d3945ec3961b4add68a8406e4d8f816ce20639fe8c0a991492b
    TSP "D-Trust GmbH"
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=D-Trust.SMCB-CA3,OU=Institution des Gesundheitswesens-CA der Telematikinfrastruktur,O=D-TRUST GmbH,C=DE
    MIIENTCCAx2gAwIBAgIBDjANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp.bdr.tsp-smc-b.telematik
    Zertifikat ("DE, D-TRUST GmbH, Institution des Gesundheitswesens-CA der Telematikinfrastruktur, D-Trust.SMCB-CA3", SN: 14, gültig bis 2026-08-15T07:29).
    SHA-1: c64e9848a35e2f733fc898a1e6f547a835c8853a
    SHA-256: 15611416ecdaed8c48f36cc10f62272eb2d41c5636d9d941a6c4d266e4b00ee5
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=D-Trust.HBA-CA1,OU=Heilberufsausweis-CA der Telematikinfrastruktur,O=DTRUS,C=DE
    MIIEHDCCAwSgAwIBAgIBBzANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp.bdr.tsp-hba.telematik
    Zertifikat ("DE, DTRUS, Heilberufsausweis-CA der Telematikinfrastruktur, D-Trust.HBA-CA1", SN: 7, gültig bis 2023-12-06T11:56).
    SHA-1: f2243b3b22776658e6d431c37f1bc4c1ae758aab
    SHA-256: 43614a6b9565f8143f990018c78567e1dabcc9d10350c1c143463bea174ee053
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=D-Trust.SMCB-CA1,OU=Institution des Gesundheitswesens-CA der Telematikinfrastruktur,O=DTRUS,C=DE
    MIIELjCCAxagAwIBAgIBCDANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp.bdr.tsp-smc-b.telematik
    Zertifikat ("DE, DTRUS, Institution des Gesundheitswesens-CA der Telematikinfrastruktur, D-Trust.SMCB-CA1", SN: 8, gültig bis 2023-12-06T11:57).
    SHA-1: ec120e565a88256fbb0741f2e614ba409bbee07e
    SHA-256: f090ae4954fa9edb5272e81e3a62d355b9becb18d783bece9c19f5b7f3f21e32
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=D-Trust.HBA-CA3,OU=Heilberufsausweis-CA der Telematikinfrastruktur,O=D-TRUST GmbH,C=DE
    MIIEIzCCAwugAwIBAgIBDTANBgkqhkiG9w0BAQsFADBtMQswCQYDVQQGEwJE
    http://ocsp.bdr.tsp-hba.telematik
    Zertifikat ("DE, D-TRUST GmbH, Heilberufsausweis-CA der Telematikinfrastruktur, D-Trust.HBA-CA3", SN: 13, gültig bis 2026-08-15T07:29).
    SHA-1: 14ded5fd38944b38938335ec668d7172747e5a7d
    SHA-256: abfbfcf35eccbe4ce428c0bc663d0622b462fe76e4b7375e813a87f16d9ceb00
    TSP "kubus IT GbR"
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    C=DE,O=kubus IT,OU=eGK PKI,CN=kubus IT eGK CA 1
    MIIEGjCCAwKgAwIBAgIIQnajwS2PXb0wDQYJKoZIhvcNAQELBQAwTjEaMBgG
    http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp
    Zertifikat ("kubus IT eGK CA 1, eGK PKI, kubus IT, DE", SN: 4789195303843487165, gültig bis 2021-07-25T14:30).
    SHA-1: 71beccac2f46f7af7503ce983b86e2f2bc56732e
    SHA-256: 3ca6ee2110a062181795f5d7bd3362a83d32c008d2a531a47c961fd8937576f4
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    C=DE,O=kubus IT,OU=eGK,CN=kubus IT eGK CA
    MIIEDzCCAvegAwIBAgIISZnor9MFDHAwDQYJKoZIhvcNAQELBQAwSDEYMBYG
    http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp
    Zertifikat ("kubus IT eGK CA, eGK, kubus IT, DE", SN: 5303525878062713968, gültig bis 2019-10-26T08:51).
    SHA-1: 83d7323a5540402e6e563a0170ec2271952718bc
    SHA-256: d004db051c6e70249bc65b352b28c64b6715008434bf30bad8bcb0c69bcc9ecf
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=KUBUS.EGK-CA4,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=kubus IT GbR,C=DE
    MIIEKDCCAxCgAwIBAgIBATANBgkqhkiG9w0BAQsFADCBgzELMAkGA1UEBhMC
    http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp
    Zertifikat ("DE, kubus IT GbR, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, KUBUS.EGK-CA4", SN: 1, gültig bis 2026-11-24T13:22).
    SHA-1: c3185d9b936eff442a48043d6f65c9a61cb06220
    SHA-256: 2f485df0ffef1139debae4ce0c53d721b4bd500d2e520cab1dcaa215420878ab
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=KUBUS.EGK-CA1,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=kubus IT GbR,C=DE
    MIIEKDCCAxCgAwIBAgIBATANBgkqhkiG9w0BAQsFADCBgzELMAkGA1UEBhMC
    http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp
    Zertifikat ("DE, kubus IT GbR, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, KUBUS.EGK-CA1", SN: 1, gültig bis 2024-04-09T14:20).
    SHA-1: 097dd2ecafc610289cf8a79daa403f1ac41fb547
    SHA-256: be2001f194a5841fb9b782ef9e201dcd188713c09f829b91f2098bd10c684e0c
    TSP "BITMARCK"
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=BITMARCK.EGK-CA13,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=BITMARCK,C=DE
    MIIEHjCCAwagAwIBAgIBATANBgkqhkiG9w0BAQsFADCBgzELMAkGA1UEBhMC
    http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk
    Zertifikat ("DE, BITMARCK, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, BITMARCK.EGK-CA13", SN: 1, gültig bis 2026-07-25T12:57).
    SHA-1: 38c2f6310fb3d659f30414fbcb8f876e671a5d81
    SHA-256: 41c6af99c6c492a554027ef33fcb54a312853f6e4fb30755154a722fe048686c
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=BITTE.EGK-CA7,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=BITMARCK,C=DE
    MIIEFDCCAvygAwIBAgIBATANBgkqhkiG9w0BAQsFADB/MQswCQYDVQQGEwJE
    http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk
    Zertifikat ("DE, BITMARCK, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, BITTE.EGK-CA7", SN: 1, gültig bis 2024-02-14T11:56).
    SHA-1: 35c9ea6220bfa8f3dfd05a401a3c4818cae1f91b
    SHA-256: a79c1941949bd11de5b8833ab20bb3d6560bf63386817cc03ddef58102588430
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    CN=BITMARCK.EGK-CA14,OU=Elektronische Gesundheitskarte-CA der Telematikinfrastruktur,O=BITMARCK,C=DE
    MIIEHjCCAwagAwIBAgIBATANBgkqhkiG9w0BAQsFADCBgzELMAkGA1UEBhMC
    http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk
    Zertifikat ("DE, BITMARCK, Elektronische Gesundheitskarte-CA der Telematikinfrastruktur, BITMARCK.EGK-CA14", SN: 1, gültig bis 2026-12-03T09:56).
    SHA-1: f017016c50364d9d21e58c99e2a41f1f1ba94d78
    SHA-256: 4a843a9e4c7c4d613e935c8967a3098c2802a1da60671cfe9d83cc5bf7f3ce46
    http://uri.etsi.org/TrstSvc/Svctype/CA/PKC
    C=DE,O=BITMARCK,OU=eGK PKI,CN=BITMARCK CA 1
    MIIEFjCCAv6gAwIBAgIIcGIzwGLaucswDQYJKoZIhvcNAQELBQAwSjEWMBQG
    http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk
    Zertifikat ("BITMARCK CA 1, eGK PKI, BITMARCK, DE", SN: 8098091981350812107, gültig bis 2019-09-28T18:42).
    SHA-1: cc685c7d3ba3a3a4f2af149032d3d6e3d7fc63be
    SHA-256: 521e10ac6b279232f4600f2456578cc1be4e72fc6d61756a9fa413410deae116
    TSP "Bundesnetzagentur"
    
    Routing-Tabelle im JSON-Format:
    {
        "07eb35f9ed657093125a08b6b6b7251b00e6d7290d37f76ca6ab5dfc8abec61b": "http://ocsp1.atos.tsp-egk.telematik",
        "097dd2ecafc610289cf8a79daa403f1ac41fb547": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "0a1f3f265f8f2d71c7965324d2f6457344be07d9c3f7e538202f0c444654a5a9": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eA.medisign.de%3A8080%2Focsp",
        "0fb5fd3c20a426033540121bf3c57cffff49cef08d25ed0e9602ced7b00152d7": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "102d3ce379054d3945ec3961b4add68a8406e4d8f816ce20639fe8c0a991492b": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "1414b6b08db8e317b17b1acc81e29108fa9fcd4b": "http://ocsp1.atos.tsp-egk.telematik",
        "14ded5fd38944b38938335ec668d7172747e5a7d": "http://ocsp.bdr.tsp-hba.telematik",
        "15611416ecdaed8c48f36cc10f62272eb2d41c5636d9d941a6c4d266e4b00ee5": "http://ocsp.bdr.tsp-smc-b.telematik",
        "159bd00d6c784d6ac8eab446e64611f939aad9ff": "http://ocsp1.atos.tsp-egk.telematik",
        "171553637d2c627f0af276ab54d65445fff29c51": "http://ocsp-smcb.tsi.tsp-smc-b.telematik/ocspr",
        "1a2efd3464f1b95c878eeec6ecbb70dbf29d1e4a3644e5f133cc7d47f5a3b8b5": "http://ocsp1.atos.tsp-egk.telematik",
        "1aed9befc190da65223f7431a0f3ebb7685e38ba": "http://ocsp-hba.tsi.tsp-hba.telematik/ocspr",
        "216c0537f4d017a4cf4389315f79589ce2303d2a52d1005b5adb91d54463ce67": "http://ocsp-hba.tsi.tsp-hba.telematik/ocspr",
        "2641ecf8115a95d37577daabb0aad6d0dba5fd61": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "28171dbbcad34bf78e15819d600b3427edb07b50": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-ePTA.medisign.de%3A8080%2Focsp",
        "2af62411667b55f3f49cf351432836fe0e93837f": "http://ocsp-smcb.tsi.tsp-smc-b.telematik/ocspr",
        "2b2710c917992dda6a05dd4469a8166bb0cf07c1": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eA.medisign.de%3A8080%2Focsp",
        "2d6d1e119c9ebc98728cb5c55e6892cbc69d43d5e9e3871282abd2499a048e2d": "http://ocsp1.atos.tsp-egk.telematik",
        "2d7d47a533ad249b23754601f22e9082567434d130c533cb7f64a52ecffee9a3": "http://ocsp.tsl.telematik/ocsp",
        "2e2de6dd2055b7b74d186788badf17bb614dd292e5159d2c42b633b27f600860": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eZAA.medisign.de%3A8080%2Focsp",
        "2f485df0ffef1139debae4ce0c53d721b4bd500d2e520cab1dcaa215420878ab": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "310819aa628051a0ddc45562d82fd4ad4c453ea7": "http://ocsp1.atos.tsp-egk.telematik",
        "32c06d315a816b3317e99156fb0ebf67f695d8ec4f8fd8b80ec856de848ba5a8": "http://ocsp1.atos.tsp-egk.telematik",
        "32c9d99143d30edfcdba2e86674ef59d65a9758c07d99aa6da206b65ad943f64": "http://ocsp-smcb.tsi.tsp-smc-b.telematik/ocspr",
        "359a170556df65a4fa5134a2473a06cd38cd502d09b1c9321ac0a6d2fd9e584b": "http://ti-ocsp-smcb.medisign.tsp-smc-b.telematik:8080/ocsp",
        "35c9ea6220bfa8f3dfd05a401a3c4818cae1f91b": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "38c2f6310fb3d659f30414fbcb8f876e671a5d81": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "38e00cdd21f740ae30e7709173c0ace227f4e79c": "http://ocsp.tsl.telematik/ocsp",
        "3ca6ee2110a062181795f5d7bd3362a83d32c008d2a531a47c961fd8937576f4": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "41c6af99c6c492a554027ef33fcb54a312853f6e4fb30755154a722fe048686c": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "42b899c13a588208599c18cf3947669de133fae6": "http://ocsp.komp-ca.telematik/ocsp",
        "43614a6b9565f8143f990018c78567e1dabcc9d10350c1c143463bea174ee053": "http://ocsp.bdr.tsp-hba.telematik",
        "4a3a8c58e3588ad290d517dfe80bddff90f19007179a6daf7ee8cc891ebaa40f": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "4a843a9e4c7c4d613e935c8967a3098c2802a1da60671cfe9d83cc5bf7f3ce46": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "4b1a00655abd865e048d69dd2f7ee6c2705a93ea": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "4c4248dd965eda8ab1732fd8c7d63e63c1a760b8": "http://ti-ocsp-smcb.medisign.tsp-smc-b.telematik:8080/ocsp",
        "4def0393a8e6f35ecc9c8e85d5bcdd4a326317ac": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-zod2.medisign.de%3A8080%2Focsp",
        "4fef05190a566ed4f8dba5fa72176711033f5ed884b546af2a724c2e250fbe33": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-zod2.medisign.de%3A8080%2Focsp",
        "521e10ac6b279232f4600f2456578cc1be4e72fc6d61756a9fa413410deae116": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "537fac865bd8eba62b0085e4862287fdee08642975ef4ef670d64e79963ced57": "http://ocsp-hba.tsi.tsp-hba.telematik/ocspr",
        "599962cd2b8439064ce546a2f95d2fd40b680e27": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eA.medisign.de%3A8080%2Focsp",
        "5f5114bb98201927908bd571e23efaf19e10bd40": "http://ocsp1.atos.tsp-egk.telematik",
        "6214f3d59dbfe44a911aa2c092750365b411f38b": "http://ocsp1.atos.tsp-egk.telematik",
        "657cbd744e7b3525bbb85f88884e4a3279bf5aa8": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "690aa71f7c224bd4f681cf5f73b6c62646ad966c": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-zod2.medisign.de%3A8080%2Focsp",
        "6abdc0383272c291672da1a141490813e7e7fe77": "http://download.crl.ti-dienste.de/crl/vpnk-ca1.crl",
        "6ed982b14798626e266b6f74cdb3435cb79cc007": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eZAA.medisign.de%3A8080%2Focsp",
        "6f91661f5727edfe3425f9cb24d327945d788f975b9bda1c25e82c49906b486e": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-ePTA.medisign.de%3A8080%2Focsp",
        "71beccac2f46f7af7503ce983b86e2f2bc56732e": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "720575b07a87dd08750d350a49e826a305522d1378628095002940fefce6e6bc": "http://ocsp1.atos.tsp-egk.telematik",
        "76d94708965eb780fb1378387279c1f9f03f664c5b8142b25521ddf46c5af141": "http://ocsp.komp-ca.telematik/ocsp",
        "7720fe98dbf9853cb489ce95b776650786a38725": "http://ocsp1.atos.tsp-egk.telematik",
        "791eb6114f23222136542fd5e2a3f071f5b0b33c914cfe336f3defdbed8b92f4": "http://ocsp1.atos.tsp-egk.telematik",
        "794be575dc1eb7497a59451fb9c54d73d52ab6c9b8b23a199a8e108186511db3": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eZAA.medisign.de%3A8080%2Focsp",
        "79e847453409da3f422b27ecbf399d208f7408b2": "http://ocsp1.atos.tsp-egk.telematik",
        "7cd46422fc3386a96678788ea0089bcd241c1b2a2b7e944b1c6e349a5ab3ea0f": "http://ocsp1.atos.tsp-egk.telematik",
        "7ed8a87f253fa18c19b0c24a498b3469696cb2b5402567a66882fa0db471b6e5": "http://ocsp1.atos.tsp-egk.telematik",
        "82bc5f221e34f7cefa1ed1b8e68eba693215e613": "http://ocsp1.atos.tsp-egk.telematik",
        "8348855a6ba8f7f4f41f86dff92122249b81019015decf3ba273f3d6724bdbd2": "http://ocsp1.atos.tsp-egk.telematik",
        "83d7323a5540402e6e563a0170ec2271952718bc": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "8d4cab56f6a5f780ccbac4fc5fe9776f6494a292": "http://ocsp1.atos.tsp-egk.telematik",
        "90a763f542945f70d0b277b410a8f39ea1fb32fe285271de0929297255171e4d": "http://ocsp1.atos.tsp-egk.telematik",
        "9150167a63834ab9c5b106c71e65065e68c7ef37c16fafaf9c8e3927cad858be": "http://ocsp1.atos.tsp-egk.telematik",
        "9ba5620fe8c439eceee7678be4d2e6430eaaf1dd": "http://ocsp1.atos.tsp-egk.telematik",
        "9d121b291082a794b6146e7c4b2d7d162023874c31970e0dbb23a4274296ba21": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "a0b7552af3291012874b9bb2250b9e7f5ff516627fb26a0115e9e7e00247c4ea": "http://ocsp1.atos.tsp-egk.telematik",
        "a79c1941949bd11de5b8833ab20bb3d6560bf63386817cc03ddef58102588430": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "a7e7605a2a91651142ba8469fd364c8d2b2cfe0ddd04ede291319498c23b62cb": "http://ocsp.komp-ca.telematik/ocsp",
        "a7ea85d6dff6ce26a887bda1e04e9cd27886a3be89e5bf897f8a6c229f2635be": "http://download.crl.ti-dienste.de/crl/vpnk-ca1.crl",
        "abfbfcf35eccbe4ce428c0bc663d0622b462fe76e4b7375e813a87f16d9ceb00": "http://ocsp.bdr.tsp-hba.telematik",
        "ac2936d16ab2ccb3a2724cd05bae4966cafcf69718ac1cbd0c5dfb3ec416b7ff": "http://ocsp1.atos.tsp-egk.telematik",
        "ad1199685faaa2e4107822804f7dae9f57f0d27404a2cd48aabca7815f2f48d9": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "ad1f31bb64352f9df766d1021aa9133b3097602e4818606fba97f633ee7154cf": "http://download.crl.ti-dienste.de/crl/vpnk-ca1.crl",
        "aea3bdb4bacc1736c80f8dd211f08beeed2eec9b9fbe1a41679cec069a1700c0": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-zod2.medisign.de%3A8080%2Focsp",
        "af30a956287ab6615c8a33d501b6d8585463314d": "http://ocsp1.atos.tsp-egk.telematik",
        "be2001f194a5841fb9b782ef9e201dcd188713c09f829b91f2098bd10c684e0c": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "c1db45fdcd755ea321e6c7a29b192e45752dcda9a8eb14e0b64e0ae209e7807c": "http://ocsp1.atos.tsp-egk.telematik",
        "c3185d9b936eff442a48043d6f65c9a61cb06220": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "c64e9848a35e2f733fc898a1e6f547a835c8853a": "http://ocsp.bdr.tsp-smc-b.telematik",
        "c730a2a3a8f94834beb0096ac147f23f5f972802": "http://ocsp1.atos.tsp-egk.telematik",
        "cc685c7d3ba3a3a4f2af149032d3d6e3d7fc63be": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "d004db051c6e70249bc65b352b28c64b6715008434bf30bad8bcb0c69bcc9ecf": "http://ocsp.kubusit.tsp-egk.telematik:8080/ocsp",
        "d4729f2fcd02dc6bb37bb2b454188ad663753aa598bc4b91d0f9295ebc7bedb9": "http://ocsp-smcb.tsi.tsp-smc-b.telematik/ocspr",
        "d4fffdef4bc1b19506bbf514bf90c3706134020ae4f0d6ca8dabf0f55bfaeb19": "http://ocsp1.atos.tsp-egk.telematik",
        "da3d0204166ab35bab313208fa7a026ad55c09f4": "http://ocsp1.atos.tsp-egk.telematik",
        "dac6a3d34ad9fb3ddf740e2a790dcfc481fc9430": "http://ocsp1.atos.tsp-egk.telematik",
        "dde4ee0a453a7fe87edce3a82af83c978ac9a6ee03f2cc9bd8972a9f6d4276f3": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eA.medisign.de%3A8080%2Focsp",
        "e159185581e551c3a4e9e5e692d2949ee32e11a7": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "e1cd791e91b46f0f51158caee5b2d231446c94a45a45b3b5c7681cf856817480": "http://ocsp1.atos.tsp-egk.telematik",
        "e295e85c6c6feccffa6462c8dccfa5c39fa4b288": "http://ocsp-hba.tsi.tsp-hba.telematik/ocspr",
        "e3b27ab778008c794fda8e5fa6b5069a0d06af62": "http://ocsp1.atos.tsp-egk.telematik",
        "ec120e565a88256fbb0741f2e614ba409bbee07e": "http://ocsp.bdr.tsp-smc-b.telematik",
        "f017016c50364d9d21e58c99e2a41f1f1ba94d78": "http://ocsp-egk.bitmarck.tsp-egk.telematik:8180/ocsp-egk",
        "f090ae4954fa9edb5272e81e3a62d355b9becb18d783bece9c19f5b7f3f21e32": "http://ocsp.bdr.tsp-smc-b.telematik",
        "f2243b3b22776658e6d431c37f1bc4c1ae758aab": "http://ocsp.bdr.tsp-hba.telematik",
        "f4e23b61186783c002aae87c64272a9276daedc3": "http://ocsp-egk.tsi.tsp-egk.telematik/ocspr",
        "f514d213ba2f31713239e61f3d9004389ba076d8": "http://ocsp1.atos.tsp-egk.telematik",
        "f6f9f0076c768d6d3762bce44515804c94237810": "http://ocsp.ocsp-proxy.telematik/ocsp/http%3A%2F%2Ffocsp-eZAA.medisign.de%3A8080%2Focsp",
        "f7b2031c7499ad6421090e05d8be0056fc7a96a4": "http://download.crl.ti-dienste.de/crl/vpnk-ca1.crl",
        "fdb5b91779bdb86b1e2957223dc2b9b38981cf4d": "http://ocsp.komp-ca.telematik/ocsp"
    }
    
